Learn R Programming

workflowr (version 1.6.0)

wflow_pre_processor: pre_processor function for workflowr

Description

This is the pre_processor function that wflow_html passes to the function output_format from the package rmarkdown. For advanced usage only.

Usage

wflow_pre_processor(
  metadata,
  input_file,
  runtime,
  knit_meta,
  files_dir,
  output_dir
)

Arguments

metadata

The metadata specified in the YAML header of the R Markdown file

input_file

Name of Markdown file created by knitr::knit to be passed to pandoc

runtime

The runtime target for rendering. static produces output intended for static files; shiny produces output suitable for use in a Shiny document (see run). The default, auto, allows the runtime target specified in the YAML metadata to take precedence, and renders for a static runtime target otherwise.

knit_meta

(For expert use) Meta data generated by knitr.

files_dir

Directory for saving intermediate files

output_dir

Output directory. An alternate directory to write the output file to (defaults to the directory of the input file).

Details

If you'd like to combine workflowr with another R Markdown output format, you may need to use wflow_pre_processor. This function only has minor effects on the style of the resulting HTML page, and is not essential for using workflowr.

See Also

wflow_html, wflow_pre_knit, wflow_post_knit